@@ -1,7 +1,7 @@
 """
 Sage Intacct init
 """
-from .sageintacctsdk import SageIntacctSDK
+from .main import SageIntacctSDK
 from .exceptions import *
 from .apis import *
 
